#------------------------------------------------------------------------------------------
# Create pdb and mol2 files.
# The output files (.pdb, .mol2) will be created in the same directory of this script file.
# NEED: OpenBabel
#------------------------------------------------------------------------------------------


# Dialog to ask the file name
filename=self.name # Default file name
dialog = Dialog.run("Create pdb and mol2 files", "OK", "Cancel") {
  layout(2,
    item(:text, :title=>"File name (Extension is no need):"),
    item(:textfield, :width=>200, :tag=>"f", :value=>filename))
}
# Exit when canceled
filename=dialog["f"]
exit if dialog[:status] != 0

# Change the atom names to "Element + number"
natoms.times { |i| atoms[i].name=atoms[i].element+(i+1).to_s }

# Save a PDB file
savepdb(filename+".pdb")

# Convert the PDB file to a scratch mol2 file
command = "obabel -ipdb "+filename+".pdb -omol2 -O scratch"
system(command)

# Read the MOLECULE section (sect1) and BOND section (sect3) of the scratch mol2 file
sect1=sect2=sect3="" # Initialize strings of the sections
n=1 # Initialize the reading line number
open("scratch", "r") do |scratch|
	while line = scratch.gets
		if n<=7 # MOLECULE section
			if n==2
				sect1 += atoms[0].res_name+"\n"
			else
				sect1 += line
			end
		elsif n>natoms+7 # BOND section
			sect3 += line
		end
		n+=1
	end
end

# Create an ATOM section (sect2)
natoms.times { |i| 
	sect2 += sprintf("%7d %-8s %9.4f %9.4f %9.4f %-7s 0  %-4s %13.4f\n", i+1, atoms[i].name, atoms[i].x, atoms[i].y, atoms[i].z, atoms[i].atom_type, atoms[i].res_name, atoms[i].charge)
}

# Create output mol2 file
mol2file = open(filename+".mol2", "w")
mol2file.print sect1+sect2+sect3
mol2file.close
